@@ -11,6 +11,7 @@ from typing import (
     Iterable,
     List,
     Optional,
+    Tuple,
     Type,
     TypeVar,
     Union,
@@ -22,8 +23,8 @@ from fastapi.responses import ORJSONResponse
 from pydantic import BaseModel as PydanticBaseModel
 from pydantic import create_model
 from pypika.terms import Term
-from tortoise.fields.relational import ForeignKeyFieldInstance, RelationalField
-from tortoise.functions import Function, Max
+from tortoise.expressions import RawSQL
+from tortoise.functions import Function
 from tortoise.models import Field, MetaInfo
 from tortoise.queryset import Q, QuerySet
 from tortoise.transactions import in_transaction
@@ -87,29 +88,32 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
     ) -> Any:
         return v
 
-    def group_by_f(self, group_by: str, field: Field) -> Union[Function, Term]:
-        return Max(group_by)
+    def group_by_f(
+        self, group_by: str, field: Field
+    ) -> Optional[Union[Function, Term]]:
+        return None
 
     def group_by(
-        self, user: UserModel, model: Type[Model], group_by: List[str]
-    ) -> QuerySet[Model]:
-        if group_by:
-            model_meta: MetaInfo = getattr(model, "_meta")
-            field_names: Iterable[str] = model_meta.fields_map.keys()
-            annotates: Dict[str, Union[Function, Term]] = {}
-            for field_name in field_names:
-                if field_name in group_by:
-                    continue
-                field = model_meta.fields_map[field_name]
-                if isinstance(field, ForeignKeyFieldInstance):
-                    field_name = f"${field_name}_id"
-                elif isinstance(field, RelationalField):
-                    continue
-                annotates[field_name] = self.group_by_f(field_name, field)
-            q = model.annotate(**annotates)
-            q = q.group_by(*group_by)
-            return q
-        return model.all()
+        self,
+        user: UserModel,
+        q: QuerySet[Model],
+        include: Iterable[str],
+        group_by: List[str],
+    ):
+        model_meta: MetaInfo = getattr(q.model, "_meta")
+        field_names: Iterable[str] = include or model_meta.fields_map.keys()
+        annotates: Dict[str, Union[Function, Term]] = {}
+        for field_name in field_names:
+            if field_name in group_by:
+                continue
+            field = model_meta.fields_map[field_name]
+            annotate = self.group_by_f(field_name, field)
+            if annotate is None:
+                continue
+            annotates[field_name] = annotate
+        q = q.annotate(**annotates)
+        q = q.group_by(*group_by)
+        return annotates, q
 
     def q(
         self,
@@ -207,6 +211,66 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
             raise HTTPNotFoundError
         return objs
 
+    def translate_kv_condition(
+        self, user: UserModel, request: Request, q: QuerySet[Model], kv: Dict[str, Any]
+    ):
+        join_infos: Dict[str, Tuple[str, bool]] = {
+            ".and": (Q.AND, False),
+            ".or": (Q.OR, False),
+            ".not": (Q.AND, True),
+            ".not_or": (Q.OR, True),
+        }
+
+        qs: List[Q] = []
+        q_kwargs: Dict[str, Any] = {}
+        for k, v in kv.items():
+            child_join_type, child_reverse = join_infos.get(k, ("", False))
+            if child_join_type:
+                if isinstance(v, dict):
+                    q, iq = self.translate_kv_condition(
+                        user, request, q, cast(Dict[str, Any], v)
+                    )
+                elif isinstance(v, list):
+                    cqs: List[Q] = []
+                    for cv in cast(List[Dict[str, Any]], v):
+                        q, ciq = self.translate_kv_condition(
+                            user,
+                            request,
+                            q,
+                            cv,
+                        )
+                        cqs.append(ciq)
+                    iq = Q(*cqs)
+                else:
+                    assert False
+                iq.join_type = child_join_type
+                if child_reverse:
+                    iq = ~iq
+                qs.append(iq)
+                continue
+
+            k = self.model.normalize_field(k)
+            v = self.translate_condition(user, q, k, v, request)
+            if isinstance(v, QuerySet):
+                q = cast(QuerySet[Model], v)
+            elif isinstance(v, Q):
+                qs.append(v)
+            elif (
+                v is not None
+                and v != ""
+                and not (isinstance(v, list) and not v)
+                and not (isinstance(v, dict) and not v)
+            ):
+                if v == "$empty":
+                    v = ""
+                q_kwargs[k] = v
+        kv_q = Q(
+            *qs,
+            **q_kwargs,
+            join_type=Q.AND,
+        )
+        return q, kv_q
+
     def bind(self, router: APIRouter):
         ListPydanticModel = self.model.list()
         DetailPydanticModel = self.model.detail()
@@ -217,7 +281,7 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
             DetailPydanticModel, List[DetailPydanticModel]  # type: ignore
         ]
         Response = create_model(
-            f"{self.model.__name__}.Response",
+            f"{self.model.__module__}.{self.model.__name__}.Response",
             __base__=PydanticBaseModel,
             total=0,
             data=(List[ListPydanticModel], ...),  # type: ignore
@@ -247,13 +311,14 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
 
                     returns: List[PydanticBaseModel] = []
                     for input in inputs:
-                        raw: Dict[str, Any] = input.dict(exclude_unset=True)
+                        raw, m2ms = self.model.process(input)
                         obj = self.model(**raw)
 
                         obj = await self.before_create(
                             current_user, obj, input, request
                         )
                         await obj.save()
+                        await obj.save_m2ms(m2ms)
                         if prefetch:
                             await obj.fetch_related(*prefetch)
 
@@ -297,6 +362,7 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
 ###### 子逻辑, 可选项: `.and` `.or` `.not` `.not_or`
 
 ```javascript
+// (name contains name2 or email contains example2.com)
 {
     ".or": {
         "name.contains": "name2",
@@ -305,13 +371,15 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
     "name.contains": "name",
     "email.contains": "example.com",
 }
-```
 
-###### 运算方式, 可选项: `and` `or` `not` `not_or`
-
-```javascript
+// (name contains name2 and email contains example2.com) or (name contains name3)
 {
-    ".logic": "or",
+    ".or": [{
+        "name.contains": "name2"
+        "email.contains": "example2.com",
+    }, {
+        "name.contains": "name3",
+    }],
     "name.contains": "name",
     "email.contains": "example.com",
 }
@@ -334,7 +402,7 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
                 group_by: List[str] = self.group_by_query(),
                 current_user: UserModel = Depends(self.get_current_user),
             ) -> Any:
-                q = self.group_by(current_user, self.model, group_by)
+                q = self.model.all()
                 q = self.q(current_user, request, q, ResourceMethod.list)
 
                 # 通用过滤方案
@@ -342,42 +410,25 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
                 if condition:
                     for raw in condition:
                         kv = cast(Any, json.loads(raw))
-                        reverse = False
-                        join_type = kv.pop(".logic", "AND").upper()
-                        if join_type == "NOT":
-                            reverse = True
-                            join_type = "AND"
-                        elif join_type == "NOT_OR":
-                            reverse = True
-                            join_type = "OR"
-                        q_kwargs: Dict[str, Any] = {}
-                        for k, v in kv.items():
-                            k = self.model.normalize_field(k)
-                            v = self.translate_condition(current_user, q, k, v, request)
-                            if isinstance(v, QuerySet):
-                                q = cast(QuerySet[Model], v)
-                            elif (
-                                v is not None
-                                and v != ""
-                                and not (isinstance(v, list) and not v)
-                                and not (isinstance(v, dict) and not v)
-                            ):
-                                if v == "$empty":
-                                    v = ""
-                                q_kwargs[k] = v
-                        condition_q = Q(
-                            **q_kwargs,
-                            join_type=join_type,
+                        q, iq = self.translate_kv_condition(
+                            current_user, request, q, kv
                         )
-                        if reverse:
-                            condition_q = ~condition_q
-                        q = q.filter(condition_q)
+                        q = q.filter(iq)
 
                 if include:
                     q = q.only(*include)
 
-                q = q.distinct()
-                total = await q.count()
+                if group_by:
+                    group_by_fields = ",".join([f"`{field}`" for field in group_by])
+                    total_q = q.annotate(
+                        total=RawSQL(f"COUNT(DISTINCT {group_by_fields})")
+                    ).values("total")
+                    total_q.group_bys = tuple()
+                    r = cast(List[Dict[str, int]], await total_q)
+                    total = r[0]["total"] if r else 0
+                else:
+                    q = q.distinct()
+                    total = await q.count()
 
                 if order_by:
                     orderings: List[str] = []
@@ -389,13 +440,15 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
 
                 q = q.offset(offset).limit(limit)
                 if group_by:
-                    dicts = cast(List[Dict[str, Any]], await q.values())
-                    return Response(
-                        total=total,
-                        data=[ListPydanticModel(**d) for d in dicts],
+                    annotates, q = self.group_by(current_user, q, include, group_by)
+                    dicts = cast(
+                        List[Dict[str, Any]],
+                        await q.values(*group_by, *annotates.keys()),
                     )
+                    objs = [self.model(**v) for v in dicts]
+                else:
+                    objs = await q
 
-                objs = await q
                 if prefetch:
                     for obj in objs:
                         await obj.fetch_related(*prefetch)
@@ -462,14 +515,19 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
                                 if isinstance(updated_at, str):
                                     updated_at = json.parse_iso_datetime(updated_at)
                                 if isinstance(updated_at, datetime):
-                                    if obj.updated_at > updated_at:
+                                    obj_updated_at = obj.updated_at.replace(
+                                        microsecond=int(
+                                            str(obj.updated_at.microsecond)[:3]
+                                        )
+                                    )
+                                    if obj_updated_at > updated_at:
                                         raise HTTPPreconditionRequiredError
 
                             obj_obj = copy(obj)
 
                             update_fields = raw.keys()
                             if update_fields:
-                                obj.update(raw)
+                                await obj.update(raw)
                                 await obj.save(update_fields=update_fields)
 
                             if prefetch:
