@@ -20,6 +20,8 @@ def dumps(record: Dict[str, Any], *args: Any, **kwargs: Any) -> str:
     lineno = record.pop("lineno", "")
     parts: List[str] = []
     for k, v in record.items():
+        if v == "" or v is None:
+            continue
         parts.append(
             "%s%s: %s%s" % (color, k, Style.RESET_ALL, json.dumps(v, *args, **kwargs))
         )
