@@ -7,6 +7,7 @@ from tortoise import Tortoise, fields
 from tortoise.backends.base.client import BaseDBAsyncClient
 from tortoise.contrib.pydantic import PydanticModel, pydantic_model_creator
 from tortoise.contrib.pydantic.creator import PydanticMeta
+from tortoise.fields.relational import ManyToManyFieldInstance
 from tortoise.models import Field, MetaInfo, Model
 
 from .fields import LocalDatetimeField
@@ -79,10 +80,11 @@ class BaseModel(Model):
             exclude=(
                 *form_exclude,
                 *(
-                    ["id", "created_at", "updated_at"]
+                    ["created_at", "updated_at"]
                     if required_override is None
-                    else ["id", "created_at"]
+                    else ["created_at"]
                 ),
+                *([] if from_models else ["id"]),
             ),
             required_override=required_override,
             from_models=from_models,
@@ -125,11 +127,44 @@ class BaseModel(Model):
             max_levels=max_levels,
         )
 
-    def update(self, input: Any):
+    @classmethod
+    def process(cls, input: Any):
         dic: Dict[str, Any] = (
             input if isinstance(input, dict) else input.dict(exclude_unset=True)
         )
+
+        # 处理 m2m
+        m2ms: Dict[str, Any] = {}
+        for m2m_field in cls._meta.m2m_fields:
+            values = dic.pop(m2m_field, None)
+            if values is None:
+                continue
+            m2ms[m2m_field] = values
+
+        return dic, m2ms
+
+    async def update(self, input: Any):
+        dic, m2ms = self.process(input)
         self.update_from_dict(dic)  # type: ignore
+        await self.save_m2ms(m2ms)
+
+    async def save_m2ms(self, m2ms: Dict[str, Any]):
+        if len(m2ms) == 0:
+            return
+
+        for m2m_field, values in m2ms.items():
+            model = cast(
+                ManyToManyFieldInstance, self._meta.fields_map[m2m_field]
+            ).related_model
+            m2m = getattr(self, m2m_field)
+            await m2m.clear()
+            for raw in values:
+                value_id = raw.get("id")
+                if value_id:
+                    value = await model.get(id=value_id)
+                else:
+                    value = await model.create(**raw)
+                await m2m.add(value)
 
     async def fetch_related(
         self, *args: Any, using_db: Optional[BaseDBAsyncClient] = None
