@@ -54,13 +54,20 @@ def patch_pydantic(
                             config=config,
                         )
 
+                        if is_form:
+                            continue
+
                     if is_form:
-                        continue
-                    field_pydantic_model: Type[Any] = orig_model.detail(
-                        from_models=from_models,
-                        required_override=required_override,
-                        max_levels=max_levels,
-                    )
+                        field_pydantic_model: Type[Any] = orig_model.form(
+                            from_models=from_models,
+                            required_override=False,
+                        )
+                    else:
+                        field_pydantic_model: Type[Any] = orig_model.detail(
+                            from_models=from_models,
+                            required_override=required_override,
+                            max_levels=max_levels,
+                        )
                     if field.shape == SHAPE_LIST:
                         field = ModelField.infer(
                             name=k,
@@ -78,13 +85,17 @@ def patch_pydantic(
                             config=config,
                         )
 
+        field.allow_none = True
         model_fields[k] = field
         if required_override is not None:
             field.required = required_override
+            if not field.required:
+                field.default = None
             continue
+
         if not field.required:
             continue
-        field.allow_none = True
+
         try:
             field.required = not issubclass(field.type_, PydanticModel)
         except TypeError:
