@@ -15,17 +15,17 @@ class RecoverableModel(BaseModel):
     class meta:
         abstract = True
 
-    def update(self, input: Any):
+    async def update(self, input: Any):
         dic: Dict[str, Any] = (
             input if isinstance(input, dict) else input.dict(exclude_unset=True)
         )
         is_deleted = dic.get("is_deleted")
         if is_deleted is not None and self.is_deleted != is_deleted:
             dic["delete_or_recover_at"] = datetime.now()
-        return super().update(dic)
+        return await super().update(dic)
 
     async def delete(self, using_db: Optional[BaseDBAsyncClient] = None) -> None:
-        self.update(
+        await self.update(
             {
                 "is_deleted": True,
                 "delete_or_recover_at": datetime.now(),
