@@ -170,9 +170,7 @@ class TestAPI:
             logging.info(
                 f"expect: {status_code}, request: {input} -> [{r.status_code}]{r.text}"
             )
-            import pdb
-
-            pdb.set_trace()
+            breakpoint()
         assert r.status_code == status_code
 
     @staticmethod
